Layout instance
===============

Classes
-------

.. currentmodule:: ansys.edb.core.layout_instance

.. autosummary::
   :toctree: _autosummary

   layout_instance.LayoutInstance
   layout_instance_context.LayoutInstanceContext
   layout_obj_instance.LayoutObjInstance
   layout_obj_instance.LayoutObjInstance2DGeometry
   layout_obj_instance.LayoutObjInstance3DGeometry
